/**
 * @fileoverview The chairseven wrapper for ARGA calls. We are wrapping
 * this object in case the data access methods need to be replaced in the future
 */

/**
 * Initialize the ARGAWrapper object. No ARGA calls are performed here so nothing
 * is needed to make it work with ARGA
 * 
 * @param {boolean} silent - If true ARGA will fail silently if session start fails
 * @constructor
 */
var ArgaWrapper = function(){
	/**
	 * Data object for the various sections of the framework
	 * 
	 * IMPORTANT: Application will fail if data is not sent in
	 * the format specified by the following objects. Please
	 * model returns after these. Please also format to appropriate
	 * types if possible
	 * 
	 * @todo These don't do anything until we can talk to ARGA but you can
	 * still load them with data to fake get calls
	 */
	
	var _debug     = false,
		_indyStudy = false;
	
	//All of the values for the advanced settings page
	var _advancedSettingsData = {faces: 1,
								 words: 0}; //array
	//All of the values for the experiment state
	var _experimentData       = { answers:{}, trials: null };
	
	//All of the values for the results page
	var _resultsData          = [
        {
            data: [[0,0],[0,0]],
            yaxis: {
                tickInterval: 100, 
                 min: 0, 
                 max: 1000
            }
        },
        
        {
            data: [[0,0],[0,0]],
            yaxis: {
                tickInterval: 10, 
                min: 0, 
                max: 100
            }
        }
    ];
	
	//give this a parent so we don't need to call window.parent all the time
	var _ARGA = window.opener || window.parent || null;
	
	/**
	 * PUBLIC METHODS START HERE 
	 */
	
	/**
	 * Set debug mode
	 */
	var setDebug = function(isDebug){
		if(Boolean(isDebug)){
			_debug = isDebug;
		}
	};
	
	/**
	 * returns the current ARGA user type
	 */
	var getUserType = function(){
		var userType = "1_student";
		
		if(typeof _ARGA.ARGA_VARS !== 'undefined' && 
		   Boolean(_ARGA.ARGA_VARS.ARGA_initialized) && 
		   !_debug){
			userType = _ARGA.Get_ARGA_Data("user_rights");
		}
		
		return userType;
	};
	
	/**
	 * Get Advanced Settings Data from ARGA
	 */
	var getAdvancedSettingsData = function(){
		var saves,
			tmpSaveTime = 0,
			tmpSetting,
			lastSave = 0,
			tmpData = {};
		
		//if we have ARGA and are not in debug pull settings from ARGA
		if(_isARGA() && !_debug){
			//set indy study mode
			if ( (_ARGA.Get_ARGA_Data('indyStudy') != "") && (parseData(_ARGA.Get_ARGA_Data('indyStudy')) == "on") ) {
				_indyStudy = true;
			}
			
			if(_indyStudy || (getUserType() == '3_instructor' && _ARGA.Get_ARGA_Data('lastAdvanceSave') != "")){				
    			//Indy study or instructor data parser

				//loop the settings object and load the data
				for(var setting in _advancedSettingsData){
                    var val = _ARGA.Get_ARGA_Data(setting);
                    
                    if (val != '') {
                        _advancedSettingsData[setting] = parseData(val);
                    }
				}
			} else if(_ARGA.Get_ARGA_Data_Class("lastAdvanceSave").length > 0){
                //regular student parser
				
                //find the most recent data
				saves = _ARGA.Get_ARGA_Data_Class("lastAdvanceSave");
				
				//loop the saves, find the most recent
				for(var save = 0; save < saves.length; save++){
					if(saves[save] > tmpSaveTime){
						tmpSaveTime = saves[save];
						lastSave = save;
					}
				}
				
				//if we have a last save load the data
				if(lastSave){
					//pull the class data for each key then use the values based on save key
					for(var setting in _advancedSettingsData) {
                        var val = _ARGA.Get_ARGA_Data_Class(setting)[lastSave];
                        
                        if (val != '') {
    						_advancedSettingsData[setting] = parseData(val);
                        }
					}
				}
			}		
		}
		
		return _advancedSettingsData;
	};
	
	/**
	 * Set Advanced Settings Data in ARGA
	 * 
	 * @param {object} data (required) - the data to push up to ARGA
	 */
	var setAdvancedSettingsData = function(data){
		if(data){				
			//validate and set the data for this
			for(var settings in _advancedSettingsData){
				if(data != ""){
					_advancedSettingsData[settings] = data[settings];
				}
				else{
					jQuery.error("Key "+settings+" not defined");
				}
			}
			
			//now set ARGA data
			if(_isARGA() && !_debug){
				//add the data to ARGA
				for(var settings in _advancedSettingsData){
					if(!isNaN(_advancedSettingsData[settings])){
						_ARGA.Set_ARGA_Data(settings,JSON.stringify(parseFloat(_advancedSettingsData[settings])));
					}
					else{
						_ARGA.Set_ARGA_Data(settings,JSON.stringify(_advancedSettingsData[settings]));
					}
				}
				
				//only save if we're an instructor
				if(_ARGA.Get_ARGA_Data("user_rights") === "3_instructor"){
					//give the instructor a grade if they don't have one so the settings will work
					if(_ARGA.Get_ARGA_Grade() < 0){
						_ARGA.Set_ARGA_Data('complete','yes');
						_ARGA.Set_ARGA_Grade(0);
					}
					
					//set the current time so I can find the most recent later
					_ARGA.Set_ARGA_Data("lastAdvanceSave",new Date().getTime());
					
					//save ARGA data
					_ARGA.Save_ARGA_Data();
				}
				else{
					if(_advancedSettingsData.indyStudy == "on"){
						_indyStudy = true;
					}
				}
			}				
			//this needs to be fixed to report status of
			//ARGA save
			return _indyStudy;
		}
		else{
			jQuery.error("No save data provided");
		}
	};
	
	var clearIndyStudyData = function(){
		var tmpData = {};
		
		if(_isARGA() && !_debug){
			//format the data to make it easier to manage
			for(var setting in _ARGA.ARGA_API.data){
				tmpData[_ARGA.ARGA_API.data[setting].key] = setting;
			}
			
			for(var setting in _advancedSettingsData){
				if(typeof tmpData[setting] != "undefined"){
					_ARGA.ARGA_API.data.splice([tmpData[setting]],1);
				}
			}
		}
	};
	
	/**
	 * Get Experiment Data from ARGA
	 */
	var getExperimentData = function(){
		//Get ARGA data
		if(_isARGA() && !_debug){
			for(data in _experimentData){
				var tmpData = _ARGA.Get_ARGA_Data(data);
				if(tmpData != ""){
					_experimentData[data] = parseData(_ARGA.Get_ARGA_Data(data));
				}
			}
		} else {
		    _experimentData = JSON.parse("{\"answers\":[{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"autonomy\"},\"reverse\":false,\"time\":3245},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"laughter\"},\"reverse\":false,\"time\":2596},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":8165},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":1232},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":3012},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":3488},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"oppression\"},\"reverse\":false,\"time\":806},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"liberation\"},\"reverse\":false,\"time\":1512},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"pleasure\"},\"reverse\":false,\"time\":1245},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"suppression\"},\"reverse\":false,\"time\":2752},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"wonderful\"},\"reverse\":false,\"time\":4214},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"restraint\"},\"reverse\":false,\"time\":893},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"coercion\"},\"reverse\":false,\"time\":1545},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"suppression\"},\"reverse\":false,\"time\":711},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":1188},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"depression\"},\"reverse\":false,\"time\":740},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"load\"},\"reverse\":false,\"time\":1040},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"burden\"},\"reverse\":false,\"time\":611},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":771},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"trouble\"},\"reverse\":false,\"time\":860},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"repression\"},\"reverse\":false,\"time\":634},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"love\"},\"reverse\":false,\"time\":770},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"restraint\"},\"reverse\":false,\"time\":793},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":746},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"load\"},\"reverse\":false,\"time\":702},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":818},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"coercion\"},\"reverse\":false,\"time\":602},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"suppression\"},\"reverse\":false,\"time\":736},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"encumber\"},\"reverse\":false,\"time\":702},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"encumber\"},\"reverse\":false,\"time\":807},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"independence\"},\"reverse\":true,\"time\":1940},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"trouble\"},\"reverse\":true,\"time\":897},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"depression\"},\"reverse\":true,\"time\":4213},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"love\"},\"reverse\":true,\"time\":884},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"oppression\"},\"reverse\":true,\"time\":5611},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"pleasure\"},\"reverse\":true,\"time\":848},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":true,\"time\":387},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"load\"},\"reverse\":true,\"time\":323},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"love\"},\"reverse\":true,\"time\":319},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"laughter\"},\"reverse\":true,\"time\":287},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"autonomy\"},\"reverse\":true,\"time\":285},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"repression\"},\"reverse\":true,\"time\":174},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"happiness\"},\"reverse\":true,\"time\":152},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"emancipation\"},\"reverse\":true,\"time\":173},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberation\"},\"reverse\":true,\"time\":83},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"autonomy\"},\"reverse\":true,\"time\":165},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"peace\"},\"reverse\":true,\"time\":106},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"repression\"},\"reverse\":true,\"time\":254},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"bondage\"},\"reverse\":true,\"time\":150},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"depression\"},\"reverse\":true,\"time\":279},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"impede\"},\"reverse\":true,\"time\":231},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"pleasure\"},\"reverse\":true,\"time\":186},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"load\"},\"reverse\":true,\"time\":198},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"bondage\"},\"reverse\":true,\"time\":185},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"load\"},\"reverse\":true,\"time\":242},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"love\"},\"reverse\":true,\"time\":365},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"restraint\"},\"reverse\":true,\"time\":220},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"lumber\"},\"reverse\":true,\"time\":265},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"hinder\"},\"reverse\":true,\"time\":287},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"coercion\"},\"reverse\":true,\"time\":151}],\"trials\":[{\"trial\":1,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"weight\",\"response\":\"bad\",\"responseTime\":1629},{\"trial\":2,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"peace\",\"response\":\"good\",\"responseTime\":876},{\"trial\":3,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"hamper\",\"response\":\"bad\",\"responseTime\":1056},{\"trial\":4,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"independence\",\"response\":\"good\",\"responseTime\":776},{\"trial\":5,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"freedom\",\"response\":\"good\",\"responseTime\":786},{\"trial\":6,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"liberation\",\"response\":\"good\",\"responseTime\":1248},{\"trial\":7,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"autonomy\",\"response\":\"good\",\"responseTime\":842},{\"trial\":8,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"hamper\",\"response\":\"bad\",\"responseTime\":798},{\"trial\":9,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"joy\",\"response\":\"good\",\"responseTime\":2080},{\"trial\":10,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"load\",\"response\":\"bad\",\"responseTime\":967},{\"trial\":11,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"laughter\",\"response\":\"good\",\"responseTime\":719},{\"trial\":12,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"wonderful\",\"response\":\"good\",\"responseTime\":707},{\"trial\":13,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"oppression\",\"response\":\"bad\",\"responseTime\":753},{\"trial\":14,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"freedom\",\"response\":\"good\",\"responseTime\":729},{\"trial\":15,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"depression\",\"response\":\"bad\",\"responseTime\":1170},{\"trial\":16,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"oppression\",\"response\":\"bad\",\"responseTime\":1079},{\"trial\":17,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"hinder\",\"response\":\"bad\",\"responseTime\":1012},{\"trial\":18,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"load\",\"response\":\"bad\",\"responseTime\":955},{\"trial\":19,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"liberty\",\"response\":\"good\",\"responseTime\":708},{\"trial\":20,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"laughter\",\"response\":\"good\",\"responseTime\":730},{\"trial\":21,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"oppression\",\"response\":\"bad\",\"responseTime\":776},{\"trial\":22,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"independence\",\"response\":\"good\",\"responseTime\":1428},{\"trial\":23,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"impede\",\"response\":\"bad\",\"responseTime\":775},{\"trial\":24,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"wonderful\",\"response\":\"good\",\"responseTime\":741},{\"trial\":25,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"happy\",\"response\":\"good\",\"responseTime\":663},{\"trial\":26,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"load\",\"response\":\"bad\",\"responseTime\":945},{\"trial\":27,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"saddle\",\"response\":\"bad\",\"responseTime\":809},{\"trial\":28,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"trouble\",\"response\":\"bad\",\"responseTime\":685},{\"trial\":29,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"burden\",\"response\":\"bad\",\"responseTime\":651},{\"trial\":30,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"restraint\",\"response\":\"bad\",\"responseTime\":663},{\"trial\":31,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"trouble\",\"response\":\"bad\",\"responseTime\":708},{\"trial\":33,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1634},{\"trial\":34,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1129},{\"trial\":35,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":848},{\"trial\":36,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":893},{\"trial\":37,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1178},{\"trial\":38,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1050},{\"trial\":39,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":870},{\"trial\":40,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":690},{\"trial\":41,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":714},{\"trial\":42,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":905},{\"trial\":43,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":792},{\"trial\":44,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":972},{\"trial\":45,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":691},{\"trial\":46,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1594},{\"trial\":47,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":841},{\"trial\":48,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"african-american\",\"responseTime\":1083},{\"trial\":49,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":961},{\"trial\":50,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1354},{\"trial\":51,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1051},{\"trial\":52,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":605},{\"trial\":53,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":999},{\"trial\":54,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":881},{\"trial\":55,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":715},{\"trial\":56,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1325},{\"trial\":57,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":646},{\"trial\":58,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":747},{\"trial\":59,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1378},{\"trial\":60,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":751},{\"trial\":61,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":775},{\"trial\":62,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":604},{\"trial\":63,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":739},{\"trial\":65,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"autonomy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":3245},{\"trial\":66,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"laughter;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":2596},{\"trial\":67,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;African-American\",\"response\":\"bad african-american\",\"responseTime\":8165},{\"trial\":68,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":1232},{\"trial\":69,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":3012},{\"trial\":70,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;African-American\",\"response\":\"good caucasian-american\",\"responseTime\":3488},{\"trial\":71,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"oppression;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":806},{\"trial\":72,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberation;African-American\",\"response\":\"bad african-american\",\"responseTime\":1512},{\"trial\":73,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"pleasure;African-American\",\"response\":\"bad african-american\",\"responseTime\":1245},{\"trial\":74,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"suppression;African-American\",\"response\":\"bad african-american\",\"responseTime\":2752},{\"trial\":75,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"wonderful;African-American\",\"response\":\"bad african-american\",\"responseTime\":4214},{\"trial\":76,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"restraint;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":893},{\"trial\":77,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"coercion;African-American\",\"response\":\"bad african-american\",\"responseTime\":1545},{\"trial\":78,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"suppression;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":711},{\"trial\":79,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":1188},{\"trial\":80,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"depression;African-American\",\"response\":\"bad african-american\",\"responseTime\":740},{\"trial\":81,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"load;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":1040},{\"trial\":82,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"burden;African-American\",\"response\":\"bad african-american\",\"responseTime\":611},{\"trial\":83,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":771},{\"trial\":84,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"trouble;African-American\",\"response\":\"bad african-american\",\"responseTime\":860},{\"trial\":85,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"repression;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":634},{\"trial\":86,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"love;African-American\",\"response\":\"bad african-american\",\"responseTime\":770},{\"trial\":87,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"restraint;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":793},{\"trial\":88,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":746},{\"trial\":89,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"load;African-American\",\"response\":\"bad african-american\",\"responseTime\":702},{\"trial\":90,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":818},{\"trial\":91,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"coercion;African-American\",\"response\":\"bad african-american\",\"responseTime\":602},{\"trial\":92,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"suppression;African-American\",\"response\":\"bad african-american\",\"responseTime\":736},{\"trial\":93,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"encumber;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":702},{\"trial\":94,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"encumber;Caucasian-American\",\"response\":\"bad african-american\",\"responseTime\":807},{\"trial\":96,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1772},{\"trial\":97,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1189},{\"trial\":98,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1786},{\"trial\":99,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":728},{\"trial\":100,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":636},{\"trial\":101,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":557},{\"trial\":102,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":842},{\"trial\":103,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":717},{\"trial\":104,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1007},{\"trial\":105,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":827},{\"trial\":106,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":972},{\"trial\":107,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1302},{\"trial\":108,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":2042},{\"trial\":109,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":960},{\"trial\":110,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1662},{\"trial\":111,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":740},{\"trial\":112,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":649},{\"trial\":113,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":2120},{\"trial\":114,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":695},{\"trial\":115,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1382},{\"trial\":116,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":683},{\"trial\":117,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":738},{\"trial\":118,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":594},{\"trial\":119,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":583},{\"trial\":120,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":493},{\"trial\":121,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":601},{\"trial\":122,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":679},{\"trial\":123,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":571},{\"trial\":124,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":533},{\"trial\":125,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":561},{\"trial\":126,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":604},{\"trial\":128,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"independence;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":1940},{\"trial\":129,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"trouble;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":897},{\"trial\":130,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"depression;African-American\",\"response\":\"good african-american\",\"responseTime\":4213},{\"trial\":131,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"love;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":884},{\"trial\":132,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"oppression;African-American\",\"response\":\"good african-american\",\"responseTime\":5611},{\"trial\":133,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"pleasure;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":848},{\"trial\":134,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":387},{\"trial\":135,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"load;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":323},{\"trial\":136,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"love;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":319},{\"trial\":137,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"laughter;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":287},{\"trial\":138,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"autonomy;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":285},{\"trial\":139,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"repression;African-American\",\"response\":\"good african-american\",\"responseTime\":174},{\"trial\":140,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"happiness;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":152},{\"trial\":141,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"emancipation;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":173},{\"trial\":142,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"liberation;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":83},{\"trial\":143,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"autonomy;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":165},{\"trial\":144,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"peace;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":106},{\"trial\":145,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"repression;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":254},{\"trial\":146,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"bondage;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":150},{\"trial\":147,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"depression;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":279},{\"trial\":148,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"impede;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":231},{\"trial\":149,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"pleasure;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":186},{\"trial\":150,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"load;African-American\",\"response\":\"good african-american\",\"responseTime\":198},{\"trial\":151,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"bondage;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":185},{\"trial\":152,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"load;African-American\",\"response\":\"good african-american\",\"responseTime\":242},{\"trial\":153,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"love;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":365},{\"trial\":154,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"restraint;African-American\",\"response\":\"good african-american\",\"responseTime\":220},{\"trial\":155,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"lumber;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":265},{\"trial\":156,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"hinder;African-American\",\"response\":\"good african-american\",\"responseTime\":287},{\"trial\":157,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"coercion;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":151}]}");
		}
		
		return _experimentData;
	};
	
	/**
	 * Get Experiment Class Data from ARGA
	 */
	var getExperimentClassData = function(){
		var tmpData    = [],
			returnData = [],
			currData   = null,
			blankKey   = [];
		
		//Get ARGA data
		if(_isARGA() && !_debug){
			if(!_indyStudy){
                // Check if the persistent data store exists.
                if (typeof _ARGA.c7_persistent !== 'undefined') {
                    // If the persistent class data is current, return that instead of parsing it again.
                    if (_ARGA.Get_ARGA_Data_Class(data).length <= _ARGA.c7_persistent.classData.length) {
                        return _ARGA.c7_persistent.classData;
                    }
                }

				for(var data in _experimentData){
					currData = _ARGA.Get_ARGA_Data_Class(data);
					
					for(var i = 0; i < currData.length; i++){
						if(typeof tmpData[i] == "undefined"){
							tmpData[i] = {};
						}
						if(currData[i] != ""){
							tmpData[i][data] = parseData(currData[i]);
						}
						else{
							tmpData[i][data] = null;
						}
					}
				}
                
                for(var i = 0; i < currData.length; i++) {
                    tmpData[i]['learner'] = _ARGA.Get_ARGA_Data_Class('learner_name')[i];
                }
				
				//splice out the empties
				for(i in tmpData){
					var blankKeys = 0,
						totalKeys = 0;
					
					for(var j in tmpData[i]){
						totalKeys++;
						if(tmpData[i][j] === null){
							blankKeys++;
						}
					}
					
					if(blankKeys < totalKeys){
						returnData.push(tmpData[i]);
					}
				}

                // Store in the persistent data store.
                if (typeof _ARGA.c7_persistent !== 'undefined') {
                    _ARGA.c7_persistent.lastUpdated = new Date().getTime();
                    _ARGA.c7_persistent.classData = returnData;
                }
			}
			//indy study mode uses student data for class data
			else{
				var tmpItem = {};
				
				for(var data in _experimentData){					
					currData = _ARGA.Get_ARGA_Data(data);
					
					if(currData != ""){
						tmpItem[data] = parseData(currData);
					}
					else{
						tmpItem[data] = null;
					}
				}
				
				returnData.push(tmpItem);
			}
		} else {
            for (var i=0; i < 20; i++) {
                var testData = JSON.parse("{\"answers\":[{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"autonomy\"},\"reverse\":false,\"time\":3245},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"laughter\"},\"reverse\":false,\"time\":2596},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":8165},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":1232},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":3012},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":3488},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"oppression\"},\"reverse\":false,\"time\":806},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"liberation\"},\"reverse\":false,\"time\":1512},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"pleasure\"},\"reverse\":false,\"time\":1245},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"suppression\"},\"reverse\":false,\"time\":2752},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"wonderful\"},\"reverse\":false,\"time\":4214},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"restraint\"},\"reverse\":false,\"time\":893},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"coercion\"},\"reverse\":false,\"time\":1545},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"suppression\"},\"reverse\":false,\"time\":711},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":1188},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"depression\"},\"reverse\":false,\"time\":740},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"load\"},\"reverse\":false,\"time\":1040},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"burden\"},\"reverse\":false,\"time\":611},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":771},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"trouble\"},\"reverse\":false,\"time\":860},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"repression\"},\"reverse\":false,\"time\":634},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"love\"},\"reverse\":false,\"time\":770},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"restraint\"},\"reverse\":false,\"time\":793},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":false,\"time\":746},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"load\"},\"reverse\":false,\"time\":702},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberty\"},\"reverse\":false,\"time\":818},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"coercion\"},\"reverse\":false,\"time\":602},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"suppression\"},\"reverse\":false,\"time\":736},{\"response\":\"Good Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"encumber\"},\"reverse\":false,\"time\":702},{\"response\":\"Bad African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"encumber\"},\"reverse\":false,\"time\":807},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"independence\"},\"reverse\":true,\"time\":1940},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"trouble\"},\"reverse\":true,\"time\":897},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"depression\"},\"reverse\":true,\"time\":4213},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"love\"},\"reverse\":true,\"time\":884},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"oppression\"},\"reverse\":true,\"time\":5611},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"pleasure\"},\"reverse\":true,\"time\":848},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"joy\"},\"reverse\":true,\"time\":387},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"load\"},\"reverse\":true,\"time\":323},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"love\"},\"reverse\":true,\"time\":319},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"laughter\"},\"reverse\":true,\"time\":287},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"autonomy\"},\"reverse\":true,\"time\":285},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"repression\"},\"reverse\":true,\"time\":174},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"happiness\"},\"reverse\":true,\"time\":152},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"emancipation\"},\"reverse\":true,\"time\":173},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"liberation\"},\"reverse\":true,\"time\":83},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"autonomy\"},\"reverse\":true,\"time\":165},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"peace\"},\"reverse\":true,\"time\":106},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"repression\"},\"reverse\":true,\"time\":254},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"bondage\"},\"reverse\":true,\"time\":150},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"depression\"},\"reverse\":true,\"time\":279},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"impede\"},\"reverse\":true,\"time\":231},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"pleasure\"},\"reverse\":true,\"time\":186},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"load\"},\"reverse\":true,\"time\":198},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"bondage\"},\"reverse\":true,\"time\":185},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"load\"},\"reverse\":true,\"time\":242},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"love\"},\"reverse\":true,\"time\":365},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"restraint\"},\"reverse\":true,\"time\":220},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"lumber\"},\"reverse\":true,\"time\":265},{\"response\":\"Good African-American\",\"answer\":{\"face\":\"African-American\",\"word\":\"hinder\"},\"reverse\":true,\"time\":287},{\"response\":\"Bad Caucasian-American\",\"answer\":{\"face\":\"Caucasian-American\",\"word\":\"coercion\"},\"reverse\":true,\"time\":151}],\"trials\":[{\"trial\":1,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"weight\",\"response\":\"bad\",\"responseTime\":1629},{\"trial\":2,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"peace\",\"response\":\"good\",\"responseTime\":876},{\"trial\":3,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"hamper\",\"response\":\"bad\",\"responseTime\":1056},{\"trial\":4,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"independence\",\"response\":\"good\",\"responseTime\":776},{\"trial\":5,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"freedom\",\"response\":\"good\",\"responseTime\":786},{\"trial\":6,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"liberation\",\"response\":\"good\",\"responseTime\":1248},{\"trial\":7,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"autonomy\",\"response\":\"good\",\"responseTime\":842},{\"trial\":8,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"hamper\",\"response\":\"bad\",\"responseTime\":798},{\"trial\":9,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"joy\",\"response\":\"good\",\"responseTime\":2080},{\"trial\":10,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"load\",\"response\":\"bad\",\"responseTime\":967},{\"trial\":11,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"laughter\",\"response\":\"good\",\"responseTime\":719},{\"trial\":12,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"wonderful\",\"response\":\"good\",\"responseTime\":707},{\"trial\":13,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"oppression\",\"response\":\"bad\",\"responseTime\":753},{\"trial\":14,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"freedom\",\"response\":\"good\",\"responseTime\":729},{\"trial\":15,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"depression\",\"response\":\"bad\",\"responseTime\":1170},{\"trial\":16,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"oppression\",\"response\":\"bad\",\"responseTime\":1079},{\"trial\":17,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"hinder\",\"response\":\"bad\",\"responseTime\":1012},{\"trial\":18,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"load\",\"response\":\"bad\",\"responseTime\":955},{\"trial\":19,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"liberty\",\"response\":\"good\",\"responseTime\":708},{\"trial\":20,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"laughter\",\"response\":\"good\",\"responseTime\":730},{\"trial\":21,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"oppression\",\"response\":\"bad\",\"responseTime\":776},{\"trial\":22,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"independence\",\"response\":\"good\",\"responseTime\":1428},{\"trial\":23,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"impede\",\"response\":\"bad\",\"responseTime\":775},{\"trial\":24,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"wonderful\",\"response\":\"good\",\"responseTime\":741},{\"trial\":25,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"happy\",\"response\":\"good\",\"responseTime\":663},{\"trial\":26,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"load\",\"response\":\"bad\",\"responseTime\":945},{\"trial\":27,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"saddle\",\"response\":\"bad\",\"responseTime\":809},{\"trial\":28,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"trouble\",\"response\":\"bad\",\"responseTime\":685},{\"trial\":29,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"burden\",\"response\":\"bad\",\"responseTime\":651},{\"trial\":30,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"restraint\",\"response\":\"bad\",\"responseTime\":663},{\"trial\":31,\"block\":\"words\",\"reverse\":false,\"stimulus\":\"trouble\",\"response\":\"bad\",\"responseTime\":708},{\"trial\":33,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1634},{\"trial\":34,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1129},{\"trial\":35,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":848},{\"trial\":36,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":893},{\"trial\":37,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1178},{\"trial\":38,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1050},{\"trial\":39,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":870},{\"trial\":40,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":690},{\"trial\":41,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":714},{\"trial\":42,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":905},{\"trial\":43,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":792},{\"trial\":44,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":972},{\"trial\":45,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":691},{\"trial\":46,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1594},{\"trial\":47,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":841},{\"trial\":48,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"african-american\",\"responseTime\":1083},{\"trial\":49,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":961},{\"trial\":50,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1354},{\"trial\":51,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1051},{\"trial\":52,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":605},{\"trial\":53,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":999},{\"trial\":54,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":881},{\"trial\":55,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":715},{\"trial\":56,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1325},{\"trial\":57,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":646},{\"trial\":58,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":747},{\"trial\":59,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1378},{\"trial\":60,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":751},{\"trial\":61,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":775},{\"trial\":62,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":604},{\"trial\":63,\"block\":\"faces\",\"reverse\":false,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":739},{\"trial\":65,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"autonomy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":3245},{\"trial\":66,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"laughter;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":2596},{\"trial\":67,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;African-American\",\"response\":\"bad african-american\",\"responseTime\":8165},{\"trial\":68,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":1232},{\"trial\":69,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":3012},{\"trial\":70,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;African-American\",\"response\":\"good caucasian-american\",\"responseTime\":3488},{\"trial\":71,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"oppression;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":806},{\"trial\":72,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberation;African-American\",\"response\":\"bad african-american\",\"responseTime\":1512},{\"trial\":73,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"pleasure;African-American\",\"response\":\"bad african-american\",\"responseTime\":1245},{\"trial\":74,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"suppression;African-American\",\"response\":\"bad african-american\",\"responseTime\":2752},{\"trial\":75,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"wonderful;African-American\",\"response\":\"bad african-american\",\"responseTime\":4214},{\"trial\":76,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"restraint;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":893},{\"trial\":77,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"coercion;African-American\",\"response\":\"bad african-american\",\"responseTime\":1545},{\"trial\":78,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"suppression;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":711},{\"trial\":79,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":1188},{\"trial\":80,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"depression;African-American\",\"response\":\"bad african-american\",\"responseTime\":740},{\"trial\":81,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"load;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":1040},{\"trial\":82,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"burden;African-American\",\"response\":\"bad african-american\",\"responseTime\":611},{\"trial\":83,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":771},{\"trial\":84,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"trouble;African-American\",\"response\":\"bad african-american\",\"responseTime\":860},{\"trial\":85,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"repression;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":634},{\"trial\":86,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"love;African-American\",\"response\":\"bad african-american\",\"responseTime\":770},{\"trial\":87,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"restraint;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":793},{\"trial\":88,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":746},{\"trial\":89,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"load;African-American\",\"response\":\"bad african-american\",\"responseTime\":702},{\"trial\":90,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"liberty;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":818},{\"trial\":91,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"coercion;African-American\",\"response\":\"bad african-american\",\"responseTime\":602},{\"trial\":92,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"suppression;African-American\",\"response\":\"bad african-american\",\"responseTime\":736},{\"trial\":93,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"encumber;Caucasian-American\",\"response\":\"good caucasian-american\",\"responseTime\":702},{\"trial\":94,\"block\":\"combined\",\"reverse\":false,\"stimulus\":\"encumber;Caucasian-American\",\"response\":\"bad african-american\",\"responseTime\":807},{\"trial\":96,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1772},{\"trial\":97,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1189},{\"trial\":98,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1786},{\"trial\":99,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":728},{\"trial\":100,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":636},{\"trial\":101,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":557},{\"trial\":102,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":842},{\"trial\":103,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":717},{\"trial\":104,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1007},{\"trial\":105,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":827},{\"trial\":106,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":972},{\"trial\":107,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1302},{\"trial\":108,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":2042},{\"trial\":109,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":960},{\"trial\":110,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":1662},{\"trial\":111,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":740},{\"trial\":112,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":649},{\"trial\":113,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":2120},{\"trial\":114,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":695},{\"trial\":115,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":1382},{\"trial\":116,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":683},{\"trial\":117,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":738},{\"trial\":118,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":594},{\"trial\":119,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":583},{\"trial\":120,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"African-American\",\"response\":\"african-american\",\"responseTime\":493},{\"trial\":121,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":601},{\"trial\":122,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":679},{\"trial\":123,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":571},{\"trial\":124,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":533},{\"trial\":125,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":561},{\"trial\":126,\"block\":\"faces\",\"reverse\":true,\"stimulus\":\"Caucasian-American\",\"response\":\"caucasian-american\",\"responseTime\":604},{\"trial\":128,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"independence;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":1940},{\"trial\":129,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"trouble;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":897},{\"trial\":130,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"depression;African-American\",\"response\":\"good african-american\",\"responseTime\":4213},{\"trial\":131,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"love;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":884},{\"trial\":132,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"oppression;African-American\",\"response\":\"good african-american\",\"responseTime\":5611},{\"trial\":133,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"pleasure;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":848},{\"trial\":134,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"joy;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":387},{\"trial\":135,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"load;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":323},{\"trial\":136,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"love;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":319},{\"trial\":137,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"laughter;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":287},{\"trial\":138,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"autonomy;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":285},{\"trial\":139,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"repression;African-American\",\"response\":\"good african-american\",\"responseTime\":174},{\"trial\":140,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"happiness;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":152},{\"trial\":141,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"emancipation;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":173},{\"trial\":142,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"liberation;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":83},{\"trial\":143,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"autonomy;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":165},{\"trial\":144,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"peace;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":106},{\"trial\":145,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"repression;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":254},{\"trial\":146,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"bondage;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":150},{\"trial\":147,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"depression;Caucasian-American\",\"response\":\"good african-american\",\"responseTime\":279},{\"trial\":148,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"impede;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":231},{\"trial\":149,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"pleasure;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":186},{\"trial\":150,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"load;African-American\",\"response\":\"good african-american\",\"responseTime\":198},{\"trial\":151,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"bondage;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":185},{\"trial\":152,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"load;African-American\",\"response\":\"good african-american\",\"responseTime\":242},{\"trial\":153,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"love;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":365},{\"trial\":154,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"restraint;African-American\",\"response\":\"good african-american\",\"responseTime\":220},{\"trial\":155,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"lumber;African-American\",\"response\":\"bad caucasian-american\",\"responseTime\":265},{\"trial\":156,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"hinder;African-American\",\"response\":\"good african-american\",\"responseTime\":287},{\"trial\":157,\"block\":\"combined\",\"reverse\":true,\"stimulus\":\"coercion;Caucasian-American\",\"response\":\"bad caucasian-american\",\"responseTime\":151}]}");
                testData.learner = 'Student ' + i; 
                
                returnData.push(testData);
            }
        }
		
		return returnData;
	};
	
	/**
	 * Set Experiment Data in ARGA
	 * 
	 * @param {object} data (required) - the data to push up to ARGA
	 */
	var setExperimentData = function(data){
		if(data){
			//Set ARGA data
			if(_isARGA() && !_debug){
				for(item in _experimentData){
					_ARGA.Set_ARGA_Data(item,JSON.stringify(data[item]));
				}
				
				//Save ARGA data
				if(!_indyStudy){
                    // Mark activity as completed.
                                    // brb: no, activity is not complete
                                    // at this point
                                    //_ARGA.Set_ARGA_Data('complete', 'yes');

                                    // Mark quiz as completed if necessary.
                                    // brb: no, activity is not complete
                                    // at this point
                                    /*
                                      if (_ARGA.Get_ARGA_Grade() < 0) {
                                        _ARGA.Set_ARGA_Grade(0);
                                      }
                                    */

					_ARGA.Save_ARGA_Data();
				}
                
                // Check if this person is already in the class data, if so, update their data, if not, add them to the end.
                if (typeof _ARGA.c7_persistent !== 'undefined') {
                    var updated = false;
                    
                    for (var i=0; i < _ARGA.c7_persistent.classData.length; i++) {
                        if (_ARGA.c7_persistent.classData[i].learner == _ARGA.Get_ARGA_Data('learner_name')) {
                            updated = true;
                            
                            for (item in _experimentData) {
                                _ARGA.c7_persistent.classData[i][item] = data[item];
                            }
                            
                            break;
                        }
                    }
                    
                    if (!updated) {
                        var new_record = { learner: _ARGA.Get_ARGA_Data('learner_name') };
                        
                        for (item in _experimentData) {
                            new_record[item] = data[item];
                        }
                        
                        _ARGA.c7_persistent.classData.push(new_record);
                    }
                    
                    _ARGA.c7_persistent.lastUpdated = new Date().getTime();
                }
			}
			
			_experimentData = data;
		}
		else{
			jQuery.error('No Experiment Data Provided');
		}
	};
	
	/**
	 * Get Results data
	 * @todo Implement your own results data from other data
	 */
	var getResultsData = function() {
        var participantResults = getExperimentData();
        var classResults = getExperimentClassData();
        
		var timeAverages       = [{time:0,count:0},{time:0,count:0}],
		    timeAveragesClass  = [{time:0,count:0},{time:0,count:0}],
		    rightAverages      = [{right:0,count:0},{right:0,count:0}],
		    rightAveragesClass = [{right:0,count:0},{right:0,count:0}];
		    highestTimeAvg     = 0;
		 
		//clean up the class data
    	var classData = [];
        
        for (var s=0; s < classResults.length; s++) {
            var result = classResults[s];
            
            if (typeof result.answers !== undefined && result.answers != null) {
                classData.push(result.answers);
            }
        }
    	
        /*
    	for(tmpData in classData){
    		if(classData[tmpData] != "" && typeof classData[tmpData] != "function" && JSON.parse(classData[tmpData]).length != 0){
    			cleanData.push(JSON.parse(classData[tmpData]));
    		}
    	}
    	
    	classData = cleanData;
        */
    	
    	//reset result data
    	_resultsData = [{data:[[],[]],yaxis:{tickInterval: 100, min: 0, max: 1000}},{data:[[],[]],yaxis:{tickInterval: 10, min: 0, max: 100}}];
        
        if (typeof participantResults.answers === 'undefined' || participantResults.answers == null) {
            participantResults.answers = [];
        }
    	
    	//do the student results for time
    	sortTime(participantResults.answers, timeAverages);

    	//then the class times
    	for(var i = 0; i < classData.length; i++){
    		sortTime(classData[i], timeAveragesClass);
    	}

    	//now get student right answer percent
    	sortRight(participantResults.answers, rightAverages)

    	//then class right answer percent
    	for(var i = 0; i < classData.length; i++){
    		sortRight(classData[i], rightAveragesClass);
    	}

    	//average the time out
    	getTimeAverage(timeAverages,_resultsData[0].data[0]);
    	getTimeAverage(timeAveragesClass,_resultsData[0].data[1]);
    	getRightAverage(rightAverages,_resultsData[1].data[0]);
    	getRightAverage(rightAveragesClass,_resultsData[1].data[1]);

    	//set up the max y for the time graph
      highestTimeAvg = highestTimeAvg * 1.1; // add some headroom
      
      if (highestTimeAvg < 900) {
        highestTimeAvg = 900;
      }
      
    	_resultsData[0].yaxis.max = highestTimeAvg + (100 - (highestTimeAvg % 100));
      _resultsData[0].yaxis.tickInterval = _resultsData[0].yaxis.max / 10;
        
		return _resultsData;
		
		/**
    	 * Sort the response time from student answers
    	 */
    	function sortTime(answers,timeAverages){
    		for(var i = 0; i < answers.length; i++){
    		    if(answers[i].reverse){
    		        timeAverages[1].time += answers[i].time;
    		        timeAverages[1].count++;
    		    }
    		    else{
    		        timeAverages[0].time += answers[i].time;
    		        timeAverages[0].count++;
    		    }
    		}
    	}

    	/**
    	 * Calculate the average time result
    	 */
    	function getTimeAverage(timeAverages,resultData){
    		for(i = 0; i < timeAverages.length; i++) {
          if (timeAverages[i].count > 0) {
              resultData.push(timeAverages[i].time/timeAverages[i].count);
              
              if (timeAverages[i].time/timeAverages[i].count > highestTimeAvg) {
                highestTimeAvg = timeAverages[i].time/timeAverages[i].count;
              }
          } else {
              resultData.push(0);
          }
    		}
    	}

    	/**
    	 * sort the right answers from student data
    	 */
    	function sortRight(answers,rightAverages){
    		for(var i = 0; i < answers.length; i++){
    		    if(answers[i].reverse){
    		    	if(answers[i].response.indexOf(answers[i].answer.face) !== -1){
    		    		rightAverages[1].right++;	
    		    	}
    		    	rightAverages[1].count++;
    		    }
    		    else{
    		    	if(answers[i].response.indexOf(answers[i].answer.face) !== -1){
    		    		rightAverages[0].right++;    
    	            }
    		    	rightAverages[0].count++;
    		    }
    		}
    	}

    	/**
    	 * Calculate the average right answer result
    	 */
    	function getRightAverage(rightAverages,resultData){
    	    for(i = 0; i < timeAverages.length; i++) {
                if (rightAverages[i].count > 0) {
                    resultData.push((rightAverages[i].right/rightAverages[i].count)*100);
                } else {
                    resultData.push(0);
                }
    	    }
    	}
	};
    
	/**
	 * Set Results Data in ARGA
	 * 
	 * @param {object} data (required) - the data to push up to ARGA
	 */
	var setResultsData = function(data){
		if(data){
			_resultsData = data;
		}
		else{
			jQuery.error('No Results Data Provided');
		}
	};
    

	/**
	 * Get the results data in CSV string format
	 * 
	 * @return {string} - the CSV string
	 */
    var getResultsCSV = function() {
        var participantResults = getExperimentData();
        
        // Start with a header row.
        var csv = '"Block","Trial Number","Reverse","Stimulus","Response","Response Time"' + "\n";
        
        if (typeof participantResults.trials !== 'undefined' && participantResults.trials != null) {
            for (var i=0; i < participantResults.trials.length; i++) {
                csv += '"' + participantResults.trials[i].block + '",';
                csv += '"' + participantResults.trials[i].trial + '",';
                csv += '"' + participantResults.trials[i].reverse + '",';
                csv += '"' + participantResults.trials[i].stimulus + '",';
                csv += '"' + participantResults.trials[i].response + '",';
                csv += '"' + participantResults.trials[i].responseTime + '"';
                csv += "\n";
            }
        }
        
        return csv;
    };
    
    var getClassResultsCSV = function() {
        var classResults = getExperimentClassData();
        
        // Start with a header row.
        var csv = '"Student","Block","Trial Number","Reverse","Stimulus","Response","Response Time"' + "\n";
        
        for (var s=0; s < classResults.length; s++) {
            var result = classResults[s];
            
            if (typeof result.trials !== 'undefined' && result.trials != null) {
                for (var i=0; i < result.trials.length; i++) {
                    csv += '"' + result.learner + '",',
                    csv += '"' + result.trials[i].block + '",';
                    csv += '"' + result.trials[i].trial + '",';
                    csv += '"' + result.trials[i].reverse + '",';
                    csv += '"' + result.trials[i].stimulus + '",';
                    csv += '"' + result.trials[i].response + '",';
                    csv += '"' + result.trials[i].responseTime + '"';
                    csv += "\n";
                }
            }
        }
        
        
        return csv;
    };
	
	/**
	 * @return the current indy study state of the object
	 */
	var isISM = function(){
		return _indyStudy;
	};
	
	/**
	 * PRIVATE METHODS START HERE 
	 */
	
	/**
	 * @return true if we have ARGA, false otherwise
	 */
	var _isARGA = function(){
		var isARGA = false;
		
		if(_ARGA &&
		   typeof _ARGA.ARGA_VARS !== 'undefined' &&
		   Boolean(_ARGA.ARGA_VARS.ARGA_initialized)){
			isARGA = true;
		} 
		
		return isARGA;
	};

    // Bulletproof (hopefully) ARGA data parsing.
    var parseData = function(value) {
        if (typeof value !== 'undefined' && value != null && value != 'undefined' && value != '') {
            try {
                return JSON.parse(value);
            } catch (e) {
                return null;
            }
        }
    };    
	
	//return public methods
	return{
		setDebug:                setDebug,
		getUserType:             getUserType,
		getAdvancedSettingsData: getAdvancedSettingsData,
		setAdvancedSettingsData: setAdvancedSettingsData,
		clearIndyStudyData:      clearIndyStudyData,
		getExperimentData:       getExperimentData,
		getExperimentClassData:  getExperimentClassData,
		setExperimentData:       setExperimentData,
		getResultsData:          getResultsData,
		setResultsData:          setResultsData,
		getResultsCSV:           getResultsCSV,
        getClassResultsCSV:      getClassResultsCSV,
		isISM:                   isISM
	};
};
